# Generated by Django 5.0.7 on 2024-08-19 12:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0057_remove_serverchatsettings_default_model_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="chatmodeloptions",
            name="chat_model",
            field=models.CharField(default="bartowski/Meta-Llama-3.1-8B-Instruct-GGUF", max_length=200),
        ),
    ]
