# Generated by Django 4.2.7 on 2024-01-18 13:24
from typing import List

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0025_clientapplication_khojuser_phone_number_and_more"),
        ("database", "0026_searchmodelconfig_cross_encoder_inference_endpoint_and_more"),
    ]

    operations: List[str] = []
