# Generated by Django 4.2.5 on 2023-11-02 01:38

from typing import Any, List

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("database", "0010_chatmodeloptions_and_more"),
        ("database", "0010_rename_embeddings_entry_and_more"),
    ]

    operations: List[Any] = []
